@@ -61,7 +61,7 @@ public:
 
     QPoint position() const;
     QSize size() const;
-    QSizeF scaledSize(xcb_render_transform_t transform) const;
+    QSizeF logicalSize() const;
 
     QString currentModeId() const;
     XRandRMode::Map modes() const;
@@ -75,12 +75,7 @@ public:
 
     KScreen::OutputPtr toKScreenOutput() const;
 
-    bool updateReplication();
-    bool setReplicationSource(xcb_randr_output_t source);
-
-    xcb_randr_output_t replicationSource() const;
-
-    xcb_render_transform_t currentTransform() const;
+    void updateLogicalSize(const KScreen::OutputPtr &output, XRandRCrtc *crtc = nullptr);
 
 private:
     void init();
@@ -89,15 +84,7 @@ private:
     static KScreen::Output::Type fetchOutputType(xcb_randr_output_t outputId, const QString &name);
     static QByteArray typeFromProperty(xcb_randr_output_t outputId);
 
-    xcb_render_transform_t getReplicationTransform(XRandROutput *source);
-
-    /**
-     * This makes an educated guess based on position, size and scale if @param output is a
-     * replication source for this output.
-     *
-     * @return true if this output can be seen as a replica of @param output
-     */
-    bool isReplicaOf(XRandROutput *output, xcb_render_transform_t ownTransform) const;
+    xcb_render_transform_t currentTransform() const;
 
     XRandRConfig *m_config;
     xcb_randr_output_t m_id;
@@ -113,7 +100,6 @@ private:
     QStringList m_preferredModes;
 
     QList<xcb_randr_output_t> m_clones;
-    xcb_randr_output_t m_replicationSource;
 
     unsigned int m_widthMm;
     unsigned int m_heightMm;
